@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::OnlyCorePrereqs; # git description: v0.022-12-ga262c55
+package Dist::Zilla::Plugin::OnlyCorePrereqs; # git description: v0.023-3-g573b029
 # ABSTRACT: Check that no prerequisites are declared that are not part of core
 # KEYWORDS: plugin distribution metadata prerequisites core
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 use Moose;
 with 'Dist::Zilla::Role::AfterBuild';
@@ -172,7 +172,8 @@ sub after_build
 
             if ($self->check_dual_life_versions or not $self->_is_dual($prereq))
             {
-                my $has = $Module::CoreList::version{$self->starting_version->stringify}{$prereq};
+                my $has = !exists($Module::CoreList::version{$self->starting_version->stringify}) ? 0
+                    : $Module::CoreList::version{$self->starting_version->stringify}{$prereq};
                 $has = version->parse($has);    # version.pm XS hates tie() - RT#87983
                 my $wanted = version->parse($prereqs->{$phase}{requires}{$prereq});
 
@@ -287,7 +288,7 @@ Dist::Zilla::Plugin::OnlyCorePrereqs - Check that no prerequisites are declared
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
